@@ -74,8 +74,8 @@ av_render_gst_now_playing_record (DmapControlPlayer * player)
 }
 
 gchar *
-av_render_gst_now_playing_artwork (DmapControlPlayer * player, guint width,
-				 guint height)
+av_render_gst_now_playing_artwork (G_GNUC_UNUSED DmapControlPlayer * player, G_GNUC_UNUSED guint width,
+                                   G_GNUC_UNUSED guint height)
 {
 	g_warning ("Now playing artwork not implemented");
 	return NULL;
@@ -137,7 +137,7 @@ av_render_gst_next_item (DmapControlPlayer * player)
 }
 
 static void
-_prev_item (DmapControlPlayer * player)
+_prev_item (G_GNUC_UNUSED DmapControlPlayer * player)
 {
 	g_warning ("Previous item not implemented");
 }
@@ -174,7 +174,7 @@ av_render_gst_cue_clear (DmapControlPlayer * player)
 
 /* FIXME: mostly copied from AVReadMetaGst */
 static void
-_pad_added_cb (GstElement *decodebin, GstPad *pad,
+_pad_added_cb (G_GNUC_UNUSED GstElement *decodebin, GstPad *pad,
               AvRenderGstPrivate *priv)
 {
         GstCaps *caps;
@@ -212,7 +212,7 @@ _return:
 }
 
 static gboolean
-_bus_cb (GstBus *bus, GstMessage *message, AvRenderGst *render)
+_bus_cb (G_GNUC_UNUSED GstBus *bus, GstMessage *message, AvRenderGst *render)
 {
 	switch (message->type) {
 	case GST_MESSAGE_ERROR:
@@ -361,7 +361,7 @@ _return:
 }
 
 GOptionGroup *
-av_render_gst_get_option_group (AvRender *render)
+av_render_gst_get_option_group (G_GNUC_UNUSED AvRender *render)
 {
 	static GOptionGroup *option_group = NULL;
 
@@ -393,7 +393,7 @@ dmapd_module_load (GTypeModule *module)
 }
 
 G_MODULE_EXPORT gboolean
-dmapd_module_unload (GTypeModule *module)
+dmapd_module_unload (G_GNUC_UNUSED GTypeModule *module)
 {
 	return TRUE;
 }
@@ -425,12 +425,12 @@ av_render_gst_init (AvRenderGst *render)
 }
 
 static void
-_finalize (GObject *self)
+_finalize (G_GNUC_UNUSED GObject *self)
 {
 }
 
 static void
-av_render_gst_class_finalize (AvRenderGstClass *klass)
+av_render_gst_class_finalize (G_GNUC_UNUSED AvRenderGstClass *klass)
 {
 }
 
