@@ -22,12 +22,12 @@
 #include "av-render.h"
 
 static void
-av_render_init (AvRender *reader)
+av_render_init (G_GNUC_UNUSED AvRender *reader)
 {
 }
 
 static void
-av_render_class_init (AvRenderClass *klass)
+av_render_class_init (G_GNUC_UNUSED AvRenderClass *klass)
 {
 }
 
@@ -89,7 +89,7 @@ av_render_get_option_group (AvRender *reader)
 }
 
 static void
-_dmap_control_player_iface_init (gpointer iface, gpointer data)
+_dmap_control_player_iface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapControlPlayerInterface *player = iface;
 
