@@ -104,12 +104,6 @@ _constructor (GType type,
 	return object;
 }
 
-static void
-dmapd_daap_record_factory_init (DmapdDmapAvRecordFactory *factory)
-{
-	factory->priv = DMAPD_DMAP_RECORD_FACTORY_GET_PRIVATE (factory);
-}
-
 static void
 dmapd_daap_record_factory_class_init (DmapdDmapAvRecordFactoryClass *klass)
 {
@@ -128,7 +122,7 @@ dmapd_daap_record_factory_class_init (DmapdDmapAvRecordFactoryClass *klass)
 }
 
 static void
-_dmap_record_factory_interface_init (gpointer iface, gpointer data)
+_dmap_record_factory_interface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapRecordFactoryInterface *factory = iface;
 
@@ -141,3 +135,9 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapAvRecordFactory, dmapd_daap_record_factory, G_
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD_FACTORY,
 					        _dmap_record_factory_interface_init)
                          G_ADD_PRIVATE (DmapdDmapAvRecordFactory))
+
+static void
+dmapd_daap_record_factory_init (DmapdDmapAvRecordFactory *factory)
+{
+	factory->priv = dmapd_daap_record_factory_get_instance_private(factory);
+}
