@@ -18,30 +18,30 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __DMAPD_DMAP_AV_RECORD_FACTORY
-#define __DMAPD_DMAP_AV_RECORD_FACTORY
+#ifndef _DMAPD_DAAP_RECORD_FACTORY_H
+#define _DMAPD_DAAP_RECORD_FACTORY_H
 
 #include <libdmapsharing/dmap.h>
 
 G_BEGIN_DECLS
 
-#define TYPE_DMAPD_DMAP_AV_RECORD_FACTORY   (dmapd_daap_record_factory_get_type ())
-#define DMAPD_DMAP_AV_RECORD_FACTORY(o)         (G_TYPE_CHECK_INSTANCE_CAST ((o), \
-				               TYPE_DMAPD_DMAP_AV_RECORD_FACTORY, \
+#define TYPE_DMAPD_DMAP_RECORD_FACTORY   (dmapd_daap_record_factory_get_type ())
+#define DMAPD_DMAP_RECORD_FACTORY(o)         (G_TYPE_CHECK_INSTANCE_CAST ((o), \
+				               TYPE_DMAPD_DMAP_RECORD_FACTORY, \
                                                 DmapdDmapAvRecordFactory))
-#define DMAPD_DMAP_AV_RECORD_FACTORY_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), \
-				               TYPE_DMAPD_DMAP_AV_RECORD_FACTORY, \
+#define DMAPD_DMAP_RECORD_FACTORY_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), \
+				               TYPE_DMAPD_DMAP_RECORD_FACTORY, \
                                                 DmapdDmapAvRecordFactoryClass))
-#define IS_DMAPD_DMAP_AV_RECORD_FACTORY(o)      (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
-                                                TYPE_DMAPD_DMAP_AV_RECORD_FACTORY))
-#define IS_DMAPD_DMAP_AV_RECORD_FACTORY_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), \
-				          TYPE_DMAPD_DMAP_AV_RECORD_FACTORY_CLASS))
-#define DMAPD_DMAP_AV_RECORD_FACTORY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
-				               TYPE_DMAPD_DMAP_AV_RECORD_FACTORY, \
+#define IS_DMAPD_DMAP_RECORD_FACTORY(o)      (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
+                                                TYPE_DMAPD_DMAP_RECORD_FACTORY))
+#define IS_DMAPD_DMAP_RECORD_FACTORY_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), \
+				          TYPE_DMAPD_DMAP_RECORD_FACTORY_CLASS))
+#define DMAPD_DMAP_RECORD_FACTORY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
+				               TYPE_DMAPD_DMAP_RECORD_FACTORY, \
                                                 DmapdDmapAvRecordFactoryClass))
-#define DMAPD_DMAP_AV_RECORD_FACTORY_GET_PRIVATE(o) \
+#define DMAPD_DMAP_RECORD_FACTORY_GET_PRIVATE(o) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-                                      TYPE_DMAPD_DMAP_AV_RECORD_FACTORY, \
+                                      TYPE_DMAPD_DMAP_RECORD_FACTORY, \
                                       DmapdDmapAvRecordFactoryPrivate))
 
 typedef struct DmapdDmapAvRecordFactoryPrivate DmapdDmapAvRecordFactoryPrivate;
@@ -57,10 +57,11 @@ typedef struct {
 
 GType                  dmapd_daap_record_factory_get_type (void);
 
-DmapRecord            *dmapd_daap_record_factory_create
-                           (DmapRecordFactory *factory,
-                            gpointer user_data);
-
-#endif /* __DMAPD_DMAP_AV_RECORD_FACTORY */
+DmapRecord            *dmapd_daap_record_factory_create(
+                            DmapRecordFactory *factory,
+                            gpointer user_data,
+                            GError **error);
 
 G_END_DECLS
+
+#endif
