@@ -35,9 +35,10 @@ static const char *_unknown = "Unknown";
 
 struct DmapdDmapAvRecordPrivate {
 	char *location;
+	char *original_location; /* Original file, not transcoded file. */
 	GArray *hash;
 	guint64 filesize;
-	const char *format;	 	/* Format, possibly after transcoding. */
+	const char *format;      /* Format, possibly after transcoding. */
 	gint mediakind;
 	char *title;
 	const char *album;
@@ -59,6 +60,7 @@ struct DmapdDmapAvRecordPrivate {
 enum {
 	PROP_0,
 	PROP_LOCATION,
+	PROP_ORIGINAL_LOCATION,
 	PROP_HASH,
 	PROP_TITLE,
 	PROP_RATING,
@@ -94,6 +96,10 @@ _set_property (GObject *object,
 			g_free (record->priv->location);
 			record->priv->location = g_value_dup_string (value);
 			break;
+		case PROP_ORIGINAL_LOCATION:
+			g_free (record->priv->original_location);
+			record->priv->original_location = g_value_dup_string (value);
+			break;
 		case PROP_HASH:
 			if (record->priv->hash) {
 				g_array_unref(record->priv->hash);
@@ -183,6 +189,9 @@ _get_property (GObject *object,
 		case PROP_LOCATION:
 			g_value_set_static_string (value, record->priv->location);
 			break;
+		case PROP_ORIGINAL_LOCATION:
+			g_value_set_static_string (value, record->priv->original_location);
+			break;
 		case PROP_HASH:
                         g_value_set_boxed (value, g_array_ref(record->priv->hash));
                         break;
@@ -512,12 +521,6 @@ _done:
 	return fnval;
 }
 
-static void
-dmapd_daap_record_init (DmapdDmapAvRecord *record)
-{
-	record->priv = DMAPD_DMAP_AV_RECORD_GET_PRIVATE (record);
-}
-
 static void
 _finalize (GObject *object);
 
@@ -550,10 +553,18 @@ dmapd_daap_record_class_init (DmapdDmapAvRecordClass *klass)
 	g_object_class_override_property (gobject_class, PROP_BITRATE, "bitrate");
 	g_object_class_override_property (gobject_class, PROP_HAS_VIDEO, "has-video");
 	g_object_class_override_property (gobject_class, PROP_MEDIAKIND, "mediakind");
+
+	g_object_class_install_property (gobject_class,
+	                                 PROP_ORIGINAL_LOCATION,
+	                                 g_param_spec_string ("original-location",
+	                                                      "original-location",
+	                                                      "original-location",
+	                                                      NULL,
+	                                                      G_PARAM_READWRITE));
 }
 
 static void
-_dmap_av_record_iface_init (gpointer iface, gpointer data)
+_dmap_av_record_iface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapAvRecordInterface *daap_record = iface;
 
@@ -564,7 +575,7 @@ _dmap_av_record_iface_init (gpointer iface, gpointer data)
 }
 
 static void
-_dmap_record_iface_init (gpointer iface, gpointer data)
+_dmap_record_iface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapRecordInterface *dmap_record = iface;
 
@@ -580,6 +591,12 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapAvRecord, dmapd_daap_record, G_TYPE_OBJECT,
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init)
                          G_ADD_PRIVATE (DmapdDmapAvRecord))
 
+static void
+dmapd_daap_record_init (DmapdDmapAvRecord *record)
+{
+	record->priv = dmapd_daap_record_get_instance_private(record);
+}
+
 static void
 _finalize (GObject *object)
 {
@@ -588,6 +605,7 @@ _finalize (GObject *object)
 	g_debug ("Free'ing record");
 
 	g_free (record->priv->location);
+	g_free (record->priv->original_location);
 	g_free (record->priv->title);
 
 	util_stringleton_unref (record->priv->format);
