@@ -51,23 +51,13 @@ dmapd_dmap_container_db_count (DmapContainerDb *db)
 }
 
 void
-dmapd_dmap_container_db_add (DmapContainerDb *db, DmapContainerRecord *record, GError **error)
+dmapd_dmap_container_db_add (DmapContainerDb *db, DmapContainerRecord *record, G_GNUC_UNUSED GError **error)
 {
         guint id = dmap_container_record_get_id (record);
 	g_object_ref (record);
 	g_hash_table_insert (DMAPD_DMAP_CONTAINER_DB (db)->priv->db, GUINT_TO_POINTER (id), record);
 }
 
-static void
-dmapd_dmap_container_db_init (DmapdDmapContainerDb *db)
-{
-	db->priv = DMAPD_DMAP_CONTAINER_DB_GET_PRIVATE (db);
-	db->priv->db = g_hash_table_new_full (g_direct_hash,
-					      g_direct_equal,
-					      NULL,
-					      g_object_unref);
-}
-
 static void
 _finalize (GObject *object)
 {
@@ -87,7 +77,7 @@ dmapd_dmap_container_db_class_init (DmapdDmapContainerDbClass *klass)
 }
 
 static void
-_dmap_container_db_interface_init (gpointer iface, gpointer data)
+_dmap_container_db_interface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapContainerDbInterface *dmap_container_db = iface;
 
@@ -104,6 +94,16 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapContainerDb, dmapd_dmap_container_db, G_TYPE_O
 						_dmap_container_db_interface_init)
                          G_ADD_PRIVATE (DmapdDmapContainerDb))
 
+static void
+dmapd_dmap_container_db_init (DmapdDmapContainerDb *db)
+{
+	db->priv = dmapd_dmap_container_db_get_instance_private (db);
+	db->priv->db = g_hash_table_new_full (g_direct_hash,
+					      g_direct_equal,
+					      NULL,
+					      g_object_unref);
+}
+
 DmapdDmapContainerDb *
 dmapd_dmap_container_db_new (void)
 {
