@@ -45,6 +45,7 @@ enum {
 };
 
 struct loc_id {
+	const gchar *key;
 	const gchar *location;
 	guint id;
 };
@@ -52,13 +53,15 @@ struct loc_id {
 static gboolean
 _path_match (gpointer key, gpointer val, gpointer user_data)
 {
-	gboolean fnval;
-	gchar *location;
+	gboolean fnval = FALSE;
+	gchar *location = NULL;
+	struct loc_id *loc_id = user_data;
 
-	((struct loc_id *) user_data)->id = GPOINTER_TO_UINT (key);
-	g_object_get (DMAP_RECORD (val), "location", &location, NULL);
+	loc_id->id = GPOINTER_TO_UINT (key);
 
-	fnval = ! strcmp (location, ((struct loc_id *) user_data)->location); 
+	g_object_get (DMAP_RECORD (val), loc_id->key, &location, NULL);
+
+	fnval = location && ! strcmp (location, loc_id->location);
 
 	g_free (location);
 
@@ -71,6 +74,8 @@ _lookup_id_by_location (const DmapDb *db, const gchar *location)
 	guint fnval = DMAP_DB_ID_BAD;
 	struct loc_id user_data;
 
+	/* Try (possibly transcoded) location ... */
+	user_data.key = "location";
 	user_data.location = location;
 	user_data.id = 0;
 
@@ -78,8 +83,23 @@ _lookup_id_by_location (const DmapDb *db, const gchar *location)
 		(GHRFunc) _path_match,
 		(gpointer) &user_data)) {
 		fnval = user_data.id;
+		goto done;
 	}
 
+	/*
+	 * ... and then original location. For example, playlists will contain
+	 * original location in the case of transcoded files.
+	 */
+	user_data.key = "original-location";
+
+	if (g_hash_table_find (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db,
+		(GHRFunc) _path_match,
+		(gpointer) &user_data)) {
+		fnval = user_data.id;
+		goto done;
+	}
+
+done:
 	return fnval;
 }
 
@@ -312,7 +332,7 @@ done:
 }
 
 static void
-_dmap_db_interface_init (gpointer iface, gpointer data)
+_dmap_db_interface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
         DmapDbInterface *dmap_db = iface;
 
@@ -331,13 +351,23 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapDbGHashTable, dmapd_dmap_db_ghashtable, G_TYPE
                          G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, _dmap_db_interface_init)
                          G_ADD_PRIVATE (DmapdDmapDbGHashTable))
 
+static void
+dmapd_dmap_db_ghashtable_init (DmapdDmapDbGHashTable *db)
+{
+	db->priv = dmapd_dmap_db_ghashtable_get_instance_private (db);
+	db->priv->db = g_hash_table_new_full (g_direct_hash,
+					      g_direct_equal,
+					      NULL,
+					      g_object_unref);
+}
+
 static GObject*
 _constructor (GType type, guint n_construct_params, GObjectConstructParam *construct_params)
 {
 	GObject *object;
 	gchar *db_dir = NULL;
 	DmapRecordFactory *factory = NULL;
-  
+
 	object = G_OBJECT_CLASS (dmapd_dmap_db_ghashtable_parent_class)->constructor (type, n_construct_params, construct_params);
 
 	g_object_get (object, "db-dir", &db_dir, "record-factory", &factory, NULL);
@@ -350,16 +380,6 @@ _constructor (GType type, guint n_construct_params, GObjectConstructParam *const
 	return object;
 }
 
-static void
-dmapd_dmap_db_ghashtable_init (DmapdDmapDbGHashTable *db)
-{
-	db->priv = DMAPD_DMAP_DB_GHASHTABLE_GET_PRIVATE (db);
-	db->priv->db = g_hash_table_new_full (g_direct_hash,
-					      g_direct_equal,
-					      NULL,
-					      g_object_unref);
-}
-
 static void
 _finalize (GObject *object)
 {
@@ -454,3 +474,54 @@ static void dmapd_dmap_db_ghashtable_class_init (DmapdDmapDbGHashTableClass *kla
 							       "Acceptable formats",
 							        G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
+
+#ifdef HAVE_CHECK
+
+#include "dmapd-daap-record.h"
+#include "dmapd-daap-record-factory.h"
+
+START_TEST(test_dmapd_dmap_db_ghashtable_lookup_by_location)
+{
+	guint id;
+	DmapDb *db;
+	DmapdDmapAvRecordFactory *factory;
+	DmapRecord *record1, *record2;
+
+	factory = g_object_new (TYPE_DMAPD_DMAP_RECORD_FACTORY, NULL);
+
+	db = DMAP_DB (util_object_from_module (TYPE_DMAPD_DMAP_DB,
+	                                       DEFAULT_MODULEDIR,
+	                                       "ghashtable",
+	                                       "record-factory",
+	                                       factory,
+	                                       NULL));
+
+	record1 = DMAP_RECORD (g_object_new(TYPE_DMAPD_DMAP_AV_RECORD, "location", "foo"));
+	record2 = DMAP_RECORD (g_object_new(TYPE_DMAPD_DMAP_AV_RECORD, "original-location", "bar"));
+
+	dmap_db_add (db, record1, NULL);
+	dmap_db_add (db, record2, NULL);
+
+	id = _lookup_id_by_location(db, "foo");
+	fail_unless (id != DMAP_DB_ID_BAD);
+
+	id = _lookup_id_by_location(db, "bar");
+	fail_unless (id != DMAP_DB_ID_BAD);
+
+	g_object_unref (db);
+	g_object_unref (factory);
+}
+END_TEST
+
+Suite *dmapd_test_dmap_db_ghashtable_suite(void)
+{
+	Suite *s = suite_create("dmapd-test-dmapd-db-ghashtable");
+
+	TCase *tc_dmapd_dmap_db_ghashtable_lookup_by_location = tcase_create("test_dmapd_dmap_db_ghashtable_lookup_by_location");
+	tcase_add_test(tc_dmapd_dmap_db_ghashtable_lookup_by_location, test_dmapd_dmap_db_ghashtable_lookup_by_location);
+	suite_add_tcase(s, tc_dmapd_dmap_db_ghashtable_lookup_by_location);
+
+	return s;
+}
+
+#endif
