@@ -36,11 +36,6 @@ enum {
 	PROP_ACCEPTABLE_FORMATS
 };
 
-static void dmapd_dmap_db_init (DmapdDmapDb *db)
-{
-	db->priv = DMAPD_DMAP_DB_GET_PRIVATE (db);
-}
-
 static void
 _set_property (GObject *object,
                guint prop_id,
@@ -161,7 +156,7 @@ _count (const DmapDb *db)
 }
 
 static void
-_dmap_db_interface_init (gpointer iface, gpointer data)
+_dmap_db_interface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapDbInterface *dmap_db = iface;
 
@@ -179,3 +174,8 @@ _dmap_db_interface_init (gpointer iface, gpointer data)
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapDb, dmapd_dmap_db, G_TYPE_OBJECT, 
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_DB, _dmap_db_interface_init)
                          G_ADD_PRIVATE (DmapdDmapDb))
+
+static void dmapd_dmap_db_init (DmapdDmapDb *db)
+{
+	db->priv = dmapd_dmap_db_get_instance_private (db);
+}
