@@ -29,6 +29,7 @@
 
 struct DmapdDmapImageRecordPrivate {
 	char *location;
+	char *original_location;
 	GArray *hash;
 	gint largefilesize;
 	gint creationdate;
@@ -46,6 +47,7 @@ struct DmapdDmapImageRecordPrivate {
 enum {
 	PROP_0,
 	PROP_LOCATION,
+	PROP_ORIGINAL_LOCATION,
 	PROP_HASH,
 	PROP_LARGE_FILESIZE,
 	PROP_CREATION_DATE,
@@ -73,6 +75,10 @@ _set_property (GObject *object,
 			g_free (record->priv->location);
 			record->priv->location = g_value_dup_string (value);
 			break;
+		case PROP_ORIGINAL_LOCATION:
+			g_free (record->priv->original_location);
+			record->priv->original_location = g_value_dup_string (value);
+			break;
 		case PROP_LARGE_FILESIZE:
 			record->priv->largefilesize = g_value_get_int (value);
 			break;
@@ -138,6 +144,9 @@ _get_property (GObject *object,
 		case PROP_LOCATION:
 			g_value_set_static_string (value, record->priv->location);
 			break;
+		case PROP_ORIGINAL_LOCATION:
+			g_value_set_static_string (value, record->priv->original_location);
+			break;
 		case PROP_LARGE_FILESIZE:
 			g_value_set_int (value, record->priv->largefilesize);
 			break;
@@ -423,11 +432,6 @@ _done:
 	return fnval;
 }
 
-static void dmapd_dpap_record_init (DmapdDmapImageRecord *record)
-{
-	record->priv = DMAPD_DPAP_RECORD_GET_PRIVATE (record);
-}
-
 static void _finalize (GObject *object);
 
 static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
@@ -450,6 +454,15 @@ static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
 	g_object_class_override_property (gobject_class, PROP_FORMAT, "format");
 	g_object_class_override_property (gobject_class, PROP_COMMENTS, "comments");
 	g_object_class_override_property (gobject_class, PROP_THUMBNAIL, "thumbnail");
+
+	g_object_class_install_property (gobject_class,
+	                                 PROP_ORIGINAL_LOCATION,
+	                                 g_param_spec_string ("original-location",
+	                                                      "original-location",
+	                                                      "original-location",
+	                                                      NULL,
+	                                                      G_PARAM_READWRITE));
+
 	g_object_class_install_property (gobject_class,
 	                                 PROP_MTIME,
                                          g_param_spec_int
@@ -461,7 +474,7 @@ static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
 }
 
 static void
-_dmap_image_record_iface_init (gpointer iface, gpointer data)
+_dmap_image_record_iface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapImageRecordInterface *dpap_record = iface;
 
@@ -471,7 +484,7 @@ _dmap_image_record_iface_init (gpointer iface, gpointer data)
 }
 
 static void
-_dmap_record_iface_init (gpointer iface, gpointer data)
+_dmap_record_iface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapRecordInterface *dmap_record = iface;
 
@@ -487,6 +500,11 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapImageRecord, dmapd_dpap_record, G_TYPE_OBJECT,
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init)
                          G_ADD_PRIVATE (DmapdDmapImageRecord))
 
+static void dmapd_dpap_record_init (DmapdDmapImageRecord *record)
+{
+	record->priv = dmapd_dpap_record_get_instance_private (record);
+}
+
 static void
 _finalize (GObject *object)
 {
@@ -498,6 +516,7 @@ _finalize (GObject *object)
 	util_stringleton_unref (record->priv->format);
 
 	g_free (record->priv->location);
+	g_free (record->priv->original_location);
 	g_free (record->priv->filename);
 	g_free (record->priv->comments);
 
