@@ -64,8 +64,8 @@ _free_globals (void)
 static gboolean
 _add_to_opt_list (const gchar *option_name,
                   const gchar *value,
-                  gpointer data,
-                  GError **error)
+                  G_GNUC_UNUSED gpointer data,
+                  G_GNUC_UNUSED GError **error)
 {
 	if (strcmp (option_name, "-m") == 0) {
 		_music_dirs = g_slist_append (_music_dirs, g_strdup (value));
@@ -144,7 +144,7 @@ done:
 }
 
 static void
-_sigterm_handler (int i)
+_sigterm_handler (G_GNUC_UNUSED int i)
 {
 	signal (SIGTERM, _sigterm_handler);
 
@@ -189,7 +189,7 @@ static void
 _log_printf(const char *log_domain,
             GLogLevelFlags level,
             const gchar *message,
-            gpointer user_data)
+            G_GNUC_UNUSED gpointer user_data)
 {
 	if (level > G_LOG_LEVEL_INFO && !_enable_debug) {
 		return;
