@@ -44,6 +44,7 @@
 #include "photo-meta-reader.h"
 #include "util.h"
 #include "util-gst.h"
+#include "playlist.h"
 
 #define DEFAULT_CONFIG_FILE            DEFAULT_SYSCONFDIR "/dmapd.conf"
 #define DEFAULT_DB_MOD                "ghashtable"
@@ -76,6 +77,7 @@ typedef struct share_def_t {
 	char         *name;
 	char         *password;
 	char        **dirs;
+	char        **playlist_dirs;
 	char        **formats;
 	char         *transcode_mimetype;
 	gboolean      enable_rt_transcode;
@@ -88,6 +90,7 @@ static GMainLoop *_loop = NULL;
 static GSList  *_share_defs               = NULL;
 static gchar  **_music_dirs               = NULL;
 static gchar  **_picture_dirs             = NULL;
+static gchar  **_playlist_dirs            = NULL;
 static gchar  **_music_formats            = NULL;
 static gchar  **_picture_formats          = NULL;
 static gchar   *_module_dir               = NULL;
@@ -128,6 +131,7 @@ _free_globals(void)
 
 	g_strfreev(_music_dirs);
 	g_strfreev(_picture_dirs);
+	g_strfreev(_playlist_dirs);
 	g_strfreev(_music_formats);
 	g_strfreev(_picture_formats);
 
@@ -159,13 +163,15 @@ _strvappend(gchar **vector, char *str)
 static gboolean
 _add_to_opt_list (const gchar *option_name,
 	         const gchar *value,
-	         gpointer data,
-	         GError **error)
+	         G_GNUC_UNUSED gpointer data,
+	         G_GNUC_UNUSED GError **error)
 {
 	if (strcmp (option_name, "-m") == 0) {
 		_music_dirs = _strvappend(_music_dirs, g_strdup(value));
 	} else if (strcmp (option_name, "-p") == 0) {
 		_picture_dirs = _strvappend(_picture_dirs, g_strdup(value));
+	} else if (strcmp (option_name, "-y") == 0) {
+		_playlist_dirs = _strvappend(_playlist_dirs, g_strdup(value));
 	} else if (strcmp (option_name, "-M") == 0) {
 		_music_formats = _strvappend(_music_formats, g_strdup(value));
 	} else if (strcmp (option_name, "-P") == 0) {
@@ -182,6 +188,7 @@ static GOptionEntry _entries[] = {
 	{ "name", 'n', 0, G_OPTION_ARG_STRING, &_share_name, "Name of media shares", NULL },
 	{ "music-dir", 'm', 0, G_OPTION_ARG_CALLBACK, _add_to_opt_list, "Music directory", NULL },
 	{ "picture-dir", 'p', 0, G_OPTION_ARG_CALLBACK, _add_to_opt_list, "Picture directory", NULL },
+	{ "playlist-dir", 'y', 0, G_OPTION_ARG_CALLBACK, _add_to_opt_list, "Playlist directory", NULL },
 	{ "music-format", 'M', 0, G_OPTION_ARG_CALLBACK, _add_to_opt_list, "Acceptable music format", NULL },
 	{ "picture-format", 'P', 0, G_OPTION_ARG_CALLBACK, _add_to_opt_list, "Acceptable picture format", NULL },
 	{ "lockpath", 'l', 0, G_OPTION_ARG_STRING, &_lockpath, "Path to lockfile", NULL },
@@ -328,7 +335,7 @@ _daemonize (void)
 	pid = g_strdup_printf ("%d", getpid ());
 
 	size = write (fd, pid, strlen (pid));
-	if (strlen (pid) != size) {
+	if (size < 0 || strlen (pid) != (size_t) size) {
 		g_error("Error writing PID file %s: %s", pidpath, strerror(errno));
 	}
 
@@ -375,7 +382,7 @@ static void
 _log_printf(const char *log_domain,
             GLogLevelFlags level,
             const gchar *message,
-            gpointer user_data)
+            G_GNUC_UNUSED gpointer user_data)
 {
 	if (level > G_LOG_LEVEL_INFO && !_enable_debug) {
 		return;
@@ -388,7 +395,7 @@ _log_printf(const char *log_domain,
 }
 
 static void
-_error_cb(DmapShare *share, GError *error, gpointer user_data)
+_error_cb(G_GNUC_UNUSED DmapShare *share, GError *error, G_GNUC_UNUSED gpointer user_data)
 {
 	g_printerr("%s\n", error->message);
 }
@@ -471,6 +478,10 @@ _serve (protocol_id_t protocol,
 		                });
 	}
 
+	if (share_def->playlist_dirs) {
+		add_playlists(share_def->playlist_dirs, db, container_db);
+	}
+
 	_loop = g_main_loop_new (NULL, FALSE);
 	share = _create_share (protocol, db, container_db, share_def);
 
@@ -537,7 +548,7 @@ _read_type(GKeyFile *keyfile, char *group)
 
 static void
 _add_share(protocol_id_t type, char *name, char *password, char **dirs,
-          char **formats, char *transcode_mimetype,
+          char **playlist_dirs, char **formats, char *transcode_mimetype,
           gboolean enable_rt_transcode)
 {
 	share_def_t *share_def = g_new0(share_def_t, 1);
@@ -546,6 +557,7 @@ _add_share(protocol_id_t type, char *name, char *password, char **dirs,
 	share_def->name                = name;
 	share_def->password            = password;
 	share_def->dirs                = dirs;
+	share_def->playlist_dirs       = playlist_dirs;
 	share_def->formats             = formats;
 	share_def->transcode_mimetype  = transcode_mimetype;
 	share_def->enable_rt_transcode = enable_rt_transcode;
@@ -558,7 +570,6 @@ _read_keyfile (void)
 {
 	GError *error = NULL;
 	GKeyFile *keyfile;
-	gint i;
 
 	keyfile = g_key_file_new ();
 
@@ -576,7 +587,7 @@ _read_keyfile (void)
 
 		shares                = g_key_file_get_groups (keyfile, &num_groups);
 
-		for (i = 0; i < num_groups; i++) {
+		for (gsize i = 0; i < num_groups; i++) {
 			if (!strcmp("General", shares[i])) {
 				/* Every group other than "General" is a share. */
 				continue;
@@ -586,6 +597,7 @@ _read_keyfile (void)
 			           g_strdup(shares[i]),
 			           _key_file_s_or_default (keyfile, shares[i], "Password", _password),
 			           g_key_file_get_string_list (keyfile, shares[i], "Dirs", NULL, NULL),
+			           g_key_file_get_string_list (keyfile, shares[i], "PlaylistDirs", NULL, NULL),
 			           g_key_file_get_string_list (keyfile, shares[i], "Acceptable-Formats", NULL, NULL),
 			           _key_file_s_or_default (keyfile, shares[i], "Transcode-Mimetype", _transcode_mimetype),
 			           _key_file_b_or_default (keyfile, shares[i], "Realtime-Transcode", _enable_rt_transcode));
@@ -598,7 +610,7 @@ _read_keyfile (void)
 }
 
 static void
-_sigterm_handler (int i)
+_sigterm_handler (G_GNUC_UNUSED int i)
 {
 	signal (SIGTERM, _sigterm_handler);
 
@@ -608,7 +620,7 @@ _sigterm_handler (int i)
 }
 
 static gboolean
-_dacp_add_guid_cb (DmapControlShare *share, gchar *guid, gpointer user_data)
+_dacp_add_guid_cb (G_GNUC_UNUSED DmapControlShare *share, gchar *guid, G_GNUC_UNUSED gpointer user_data)
 {
 	// FIXME: handle multiple remotes? See also defn of _guid.
 	_guid = g_strdup (guid);
@@ -616,7 +628,7 @@ _dacp_add_guid_cb (DmapControlShare *share, gchar *guid, gpointer user_data)
 }
 
 static gboolean
-_dacp_lookup_guid_cb (DmapControlShare *share, gchar *guid, gpointer user_data)
+_dacp_lookup_guid_cb (G_GNUC_UNUSED DmapControlShare *share, gchar *guid, G_GNUC_UNUSED gpointer user_data)
 {
 	g_debug("Comparing %s to %s", _guid, guid);
 	return _guid && ! strcmp (_guid, guid);
@@ -625,8 +637,8 @@ _dacp_lookup_guid_cb (DmapControlShare *share, gchar *guid, gpointer user_data)
 static void
 _dacp_remote_found_cb(DmapControlShare *share,
                       gchar *service_name,
-                      gchar *display_name,
-                      gpointer user_data)
+                      G_GNUC_UNUSED gchar *display_name,
+                      G_GNUC_UNUSED gpointer user_data)
 {
 	// FIXME:
 	g_print ("Enter passcode: ");
@@ -638,13 +650,13 @@ _dacp_remote_found_cb(DmapControlShare *share,
 }
 
 static void
-_dacp_player_updated_cb(DmapControlPlayer *player, DmapControlShare *share)
+_dacp_player_updated_cb(G_GNUC_UNUSED DmapControlPlayer *player, DmapControlShare *share)
 {
 	dmap_control_share_player_updated (share);
 }
 
 static void
-_raop_service_added_cb (DmapMdnsBrowser *browser,
+_raop_service_added_cb (G_GNUC_UNUSED DmapMdnsBrowser *browser,
                         DmapMdnsService *service,
                         workers_t *workers)
 {
@@ -822,7 +834,7 @@ main (int argc, char *argv[])
 		}
 
 		_add_share(DAAP, _share_name, _password, _music_dirs,
-		           _music_formats, _transcode_mimetype,
+		           _playlist_dirs, _music_formats, _transcode_mimetype,
 		           _enable_rt_transcode);
 	}
 
@@ -832,7 +844,7 @@ main (int argc, char *argv[])
 		}
 
 		_add_share(DPAP, _share_name, _password, _picture_dirs,
-		           _picture_formats, NULL, FALSE);
+		           NULL, _picture_formats, NULL, FALSE);
 	}
 
 	if (_enable_version) {
