@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __DMAPD
-#define __DMAPD
+#ifndef _DMAPD_H
+#define _DMAPD_H
 
 #include <dmapd/av-meta-reader.h>
 #include <dmapd/photo-meta-reader.h>
