@@ -66,12 +66,6 @@ _get_property (GObject *object,
 	}
 } 
 
-static void
-photo_meta_reader_init (PhotoMetaReader *reader)
-{
-	reader->priv = PHOTO_META_READER_GET_PRIVATE (reader);
-}
-
 static void
 photo_meta_reader_class_init (PhotoMetaReaderClass *klass)
 {
@@ -96,6 +90,12 @@ G_DEFINE_TYPE_WITH_CODE (PhotoMetaReader,
                          G_TYPE_OBJECT,
                          G_ADD_PRIVATE (PhotoMetaReader))
 
+static void
+photo_meta_reader_init (PhotoMetaReader *reader)
+{
+	reader->priv = photo_meta_reader_get_instance_private (reader);
+}
+
 gboolean
 photo_meta_reader_read (PhotoMetaReader *reader,
                         DmapImageRecord *record,
