@@ -20,8 +20,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __DMAPD_UTIL_GST
-#define __DMAPD_UTIL_GST
+#ifndef _UTIL_GST_H
+#define _UTIL_GST_H
 
 #include <glib.h>
 #include <gst/gst.h>
@@ -34,8 +34,8 @@ typedef struct {
 } db_dir_and_target_transcode_mimetype_t;
 
 // FIXME: split into two different impl.: GstElement *setup_pipeline (const char *sinkname);
-gboolean pads_compatible (GstPad *pad1, GstPad *pad2);
-gboolean transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout);
-void     transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t* df);
+gboolean util_gst_pads_compatible (GstPad *pad1, GstPad *pad2);
+gboolean util_gst_transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout);
+void     util_gst_transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t* df);
 
 #endif
